%macro adjustFrame ( frame , aspectRatio=1 , frameMargin=.1 ) ;
/*
Macro takes a data set with one observation defining a bounding box.
Returns, in macro variables, a new enlarged bounding box
	Input:	Frame - a dataset which should contain one observation 
				and the variables left-right-top-bottom
			AspectRatio - The aspectratio of the new frame
			FrameMargin - How much to add
	Output:	Macrovariables left-right-top-bottom.

Frank Poppe
PW Consulting, the Netherlands
Frank.Poppe@PWconsulting.nl
*/

%global left right bottom top ;

data _NULL_ ;
	set &frame ;
	rangeHor = right - left;
	rangeVer = top - bottom;
	aspectRatio=&aspectRatio ;

	/* create anyway a margin around the areas */
	deltaRange = &frameMargin * max ( rangeHor , rangeVer );

	left = left - deltaRange;
	right = right + deltaRange;
	top = top + deltaRange;
	bottom = bottom - deltaRange;
	rangeHor = right - left;
	rangeVer = top - bottom;
	currentRatio = rangeVer / rangeHor;

	if currentRatio > aspectRatio then
		do;
			deltaRange = .5 * ( rangeVer / aspectRatio - rangeHor );
			left = left - deltaRange;
			right = right + deltaRange;
			rangeHor = rangeHor + 2 * deltaRange;
		end;
	else
		do;
			deltaRange = .5 * ( aspectRatio * rangeHor - rangeVer );
			bottom = bottom - deltaRange;
			top = top + deltaRange;
			rangeVer = rangeVer + 2 * deltaRange;
		end;

	call symputX ( 'left' , put ( left , 12.3 ) );
	call symputX ( 'right' , put ( right , 12.3 ) );
	call symputX ( 'bottom' , put ( bottom , 12.3 ) );
	call symputX ( 'top' , put ( top , 12.3 ) );
run;
%mend ;
